DefaultFlutterEdgeAiRuntime class
Default runtime that delegates to gemma.FlutterEdgeAi static methods.
- Implemented types
Constructors
- DefaultFlutterEdgeAiRuntime()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getActiveEmbedder(
{PreferredBackend? preferredBackend}) → Future< EmbeddingModel> -
Retrieves the active embedding model.
override
-
getActiveModel(
{int maxTokens = 1024, bool supportImage = false, bool supportAudio = false, bool? enableSpeculativeDecoding, PreferredBackend? preferredBackend, PreferredBackend? preferredVisionBackend, PreferredBackend? preferredAudioBackend}) → Future< InferenceModel> -
Retrieves the active inference model with the given configuration.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited