FlutterEdgeAiPluginHandle class

Convenience handle for referencing flutter-edge-ai models and embedders.

Usage:

final response = await ai.generate(
  model: flutterEdgeAi.model('gemma-3-nano'),
  prompt: 'Hello!',
);

Constructors

FlutterEdgeAiPluginHandle()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

embedder(String name) → EmbedderRef<FlutterEdgeAiEmbedConfig>
Returns an EmbedderRef for the given embedder name registered by this plugin.
model(String name) → ModelRef<FlutterEdgeAiModelOptions>
Returns a ModelRef for the given model name registered by this plugin.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited